/*
*  Integrator.cpp
*  crazyCamera
*
*  Created by Syed Reza Ali on 4/6/10.
*  Copyright 2010 University of California, Santa Barbara. All rights reserved.
*
*/

#include "Integrator.h"

#define DAMPING 0.5f; 
#define ATTRACTION 0.2f; 
#define MASS 1.0f; 


Integrator::Integrator() 
{ 
	init(); 
}


Integrator::Integrator(float v) 
{
	init(); 
	value = v;
}


Integrator::Integrator(float v, float d, float a) 
{	
	init(); 
	value = v;
	damping = d;
	attraction = a;
}


void Integrator::set(float v) 
{
	value = v;
}


void Integrator::update() 
{
	if (targeting) {
		force += attraction * (itarget - value);      
	}

	accel = force / mass;
	vel = (vel + accel) * damping;
	value += vel;

	force = 0;
}


void Integrator::target(float t) 
{
	targeting = true;
	itarget = t;
}


void Integrator::noTarget() 
{
	targeting = false;
}

void Integrator::init()
{
	value = 0.0;
	vel = 0.0;
	accel = 0.0;
	force = 0.0;	
	damping = DAMPING;
	attraction = ATTRACTION;
	mass = MASS; 	
	targeting = true;	
	itarget = 0.0; 
}